==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/openShop/AddressInfo.java <==
package eleme.openapi.sdk.api.entity.openShop;

public class AddressInfo{

    /**
     * 省级id
     */
    private Integer provinceId;
    public Integer getProvinceId() {
        return provinceId;
    }
    public void setProvinceId(Integer provinceId) {
        this.provinceId = provinceId;
    }
    
    /**
     * 省份名称
     */
    private String provinceName;
    public String getProvinceName() {
        return provinceName;
    }
    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }
    
    /**
     * 城市id
     */
    private Integer cityId;
    public Integer getCityId() {
        return cityId;
    }
    public void setCityId(Integer cityId) {
        this.cityId = cityId;
    }
    
    /**
     * 城市名称
     */
    private String cityName;
    public String getCityName() {
        return cityName;
    }
    public void setCityName(String cityName) {
        this.cityName = cityName;
    }
    
    /**
     * 区级id
     */
    private Integer districtId;
    public Integer getDistrictId() {
        return districtId;
    }
    public void setDistrictId(Integer districtId) {
        this.districtId = districtId;
    }
    
    /**
     * 区名称
     */
    private String districtName;
    public String getDistrictName() {
        return districtName;
    }
    public void setDistrictName(String districtName) {
        this.districtName = districtName;
    }
    
    /**
     * 详细地址
     */
    private String address;
    public String getAddress() {
        return address;
    }
    public void setAddress(String address) {
        this.address = address;
    }
    
    /**
     * 经度
     */
    private Double longitude;
    public Double getLongitude() {
        return longitude;
    }
    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }
    
    /**
     * 纬度
     */
    private Double latitude;
    public Double getLatitude() {
        return latitude;
    }
    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/openShop/AddressInfo.java <==
package eleme.openapi.sdk.api.entity.openShop;

import eleme.openapi.sdk.api.enumeration.openShop.*;
import eleme.openapi.sdk.api.entity.openShop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class AddressInfo{

    /**
     * 省级id
     */
    private Integer provinceId;
    public Integer getProvinceId() {
        return provinceId;
    }
    public void setProvinceId(Integer provinceId) {
        this.provinceId = provinceId;
    }
    
    /**
     * 省份名称
     */
    private String provinceName;
    public String getProvinceName() {
        return provinceName;
    }
    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }
    
    /**
     * 城市id
     */
    private Integer cityId;
    public Integer getCityId() {
        return cityId;
    }
    public void setCityId(Integer cityId) {
        this.cityId = cityId;
    }
    
    /**
     * 城市名称
     */
    private String cityName;
    public String getCityName() {
        return cityName;
    }
    public void setCityName(String cityName) {
        this.cityName = cityName;
    }
    
    /**
     * 区级id
     */
    private Integer districtId;
    public Integer getDistrictId() {
        return districtId;
    }
    public void setDistrictId(Integer districtId) {
        this.districtId = districtId;
    }
    
    /**
     * 区名称
     */
    private String districtName;
    public String getDistrictName() {
        return districtName;
    }
    public void setDistrictName(String districtName) {
        this.districtName = districtName;
    }
    
    /**
     * 详细地址
     */
    private String address;
    public String getAddress() {
        return address;
    }
    public void setAddress(String address) {
        this.address = address;
    }
    
    /**
     * 经度
     */
    private Double longitude;
    public Double getLongitude() {
        return longitude;
    }
    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }
    
    /**
     * 纬度
     */
    private Double latitude;
    public Double getLatitude() {
        return latitude;
    }
    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }
    
}
